@@ -105,6 +105,8 @@ class App:
             self.add_middleware(DefaultMiddleware)
 
         self.collections = []
+        
+        self.app.add_route("/static/{filename}", self.static_app)
 
     async def wsgi_app(self, scope, recieve, send):
         request = Request(scope, recieve=recieve)
@@ -114,12 +116,6 @@ class App:
         await response(scope, recieve, send)
 
     async def __call__(self, scope, recieve, send):
-        path_info = scope["path"]
-
-        if path_info.startswith("/static") or path_info.startswith("static"):
-            scope["PATH_INFO"] = path_info[len("/static"):]
-            await self.static_app(scope, recieve, send)
-
         await self.middleware(scope, recieve, send)
 
     def handle_request(self, request):
